_`umbra.components.factory.scriptEditor.searchInFiles`
======================================================

.. automodule:: umbra.components.factory.scriptEditor.searchInFiles

Module Attributes
-----------------

.. attribute:: umbra.components.factory.scriptEditor.searchInFiles.LOGGER

.. attribute:: umbra.components.factory.scriptEditor.searchInFiles.UI_FILE

Classes
-------

.. autoclass:: SearchInFiles
	:show-inheritance:
	:members:

